In this project, we'll replace the battery power source we used in the previous project with power from the Raspberry Pi.

So far, we've built our first circuit — both on and off the breadboard — using our 3V (3 volt) battery as our power source. But, there's no reason we couldn't power our circuits with another power source instead. In fact, using the 3V battery is probably not the best choice for a power source, as it will eventually run out of power and won't be able to provide enough power to drive our larger circuits.

It's very common for breadboards to use power sources other than batteries. For example, you can purchase a separate power supply that plugs into a wall. Luckily, with the Ready Set STEM CREATOR Kit, we don't need a separate power supply, as the kit comes with it's own power supply — the Raspberry Pi.

The kit can use power directly from the Raspberry Pi to power the breadboard. The power is made available to the breadboard through the Lid Connector Board (the green board on the top of the lid — see diagrams below). Of course, the Raspberry Pi doesn't magically create the electrical energy needed to power the breadboard — it comes from the power company, as we learned in .

In this project, we're going to replace the 3V battery we've been using as our power supply with the internal power provided by the Raspberry Pi. Other than replacing the battery with a different power source, our circuit will remain exactly the same. In fact, our schematic won't change, other than to replace the power source with 3.3V (the voltage of the Raspberry Pi power source) from the 3V provided by the battery.

Here is a reminder of that schematic:

And here are step-by-step instructions for how we make the change to the circuit (assuming you are starting where you left off in the previous project, ):

### Disconnect the 3V battery

First, we need to disconnect our existing power source. From the breadboard, remove the battery (along with the wires attached to it).

Your breadboard should now look like this:

### Add power and ground from the Lid Connector Board

We can now add power from the Lid Connector Board to the breadboard. This is accomplished by running a wire from one of the pins labeled "3.3V" on the Lid Connector Board to the red (power) row, thus providing power to the entire row. And then running a wire from the blue (ground) row to one of the pins labeled "GND" on the Lid Connector Board.

At this point, our LED should once again be lit, and our breadboard should now look like this:

We have successfully replaced the battery (our previous power source) with power and ground coming directly from the Raspberry Pi. For all future projects, we'll be using the power from the Raspberry Pi to power our circuits.

A Note About Wires

Your CREATOR Kit comes with a bag of 65 wires in assorted colors and lengths, as well as a smaller bag of 20 half-inch green wires. All the wires provided in the kit (regardless of color and length) work exactly the same way and are completely interchangeable. While you can use any wire for any purpose, there are some conventions that will help make wiring and troubleshooting your circuits much easier:

1. You should typically try to use the shortest length of wire possible that will allow you to connect the points you are trying to connect. Doing this will help keep your breadboard from becoming a big mess of wires that are hard to follow, and will make accessing your components easier.

2. Additionally, using the small green wires (which sit flush with the breadboard) is typically preferred over the longer wires when you have just a short run from one component to another.

3. While not required, convention is to use red wires to indicate power and black wires to indicate ground. Again, this isn't required, but by doing this, it will be quicker to determine how the key points of your circuit (power and ground) are wired at any given time.

4. When you start wiring lots of components, your breadboard can get a little messy and it can be difficult to determine where a wire starts and ends. For this reason, we recommend trying to use different color wires within your circuits. This will make troubleshooting much easier.

1. The circuit shown uses the 3.3V pin in the upper-left corner of the Lid Connector board. There's another 3.3V pin on the Lid Connector board — does it work the same?

2. Likewise, there are 8 ground (GND) pins on the Lid Connector board. Try a different one. Does it work the same?

3. What happens if you connect more than one ground (GND) pin to the blue ground rail at the same time? Why?